"use strict";
var __rest = (this && this.__rest) || function (s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ComponentLabel = void 0;
const react_1 = __importDefault(require("react"));
const classnames_1 = __importDefault(require("classnames"));
const component_id_1 = require("@teambit/component-id");
const duo_component_bubble_1 = require("./duo-component-bubble");
const default_label_1 = require("./default-label");
/**
 * Given a component id, shows a label for it and its scope, with a link to its bit.dev entry.
 * @name ComponentLabel
 * @example
 * <ComponentLabel bitId="kutorg.nerv/atoms/lcl" versionOverride="1.5.3" />
 */
function ComponentLabel(props) {
    const { bitId, versionOverride, fullScopeName, className, baseUrl } = props, rest = __rest(props, ["bitId", "versionOverride", "fullScopeName", "className", "baseUrl"]);
    if (!bitId)
        return null;
    let parsed = component_id_1.ComponentID.tryFromString(bitId);
    if (versionOverride)
        parsed = parsed === null || parsed === void 0 ? void 0 : parsed.changeVersion(versionOverride);
    // local or malformed component ids may fail parsing
    if (!parsed) {
        return (react_1.default.createElement(default_label_1.DefaultLabel, Object.assign({ elevation: "medium", className: className }, rest), bitId));
    }
    return (react_1.default.createElement(duo_component_bubble_1.DuoComponentBubble, Object.assign({ bitId: parsed, elevation: "medium", className: (0, classnames_1.default)(className), fullScopeName: fullScopeName, baseUrl: baseUrl }, rest)));
}
exports.ComponentLabel = ComponentLabel;
ComponentLabel.defaultProps = {
    fullScopeName: true,
};
//# sourceMappingURL=component-label.js.map