import React, { Component } from 'react';
export declare type ComponentBorderProps = {
    /** DOM element to highlight */
    targetElement?: HTMLElement;
    /** Actively recalculate position, to support moving elements  */
    motionTracking?: boolean;
} & React.HTMLAttributes<HTMLDivElement>;
/**
 * Highlight a component using a border.<br/>
 * The border is positioned at the top left of the component using [Popper.js](https://popper.js.org/),
 * and covers the element from edge to edge. The border does not interfere with normal user flow,
 * using `pointer-events: none; user-select: none;`.
 *
 * @name OverlayBorder
 * @example
 * this.elementRef = react.createRef();
 * //...
 * <OverlayBorder targetElement={this.elementRef.current} />
 */
export declare class OverlayBorder extends Component<ComponentBorderProps> {
    private popperInstance?;
    private ref;
    componentDidMount(): void;
    componentWillUnmount(): void;
    componentDidUpdate(prevProps: ComponentBorderProps): void;
    private reposition;
    private step;
    private destroy;
    render(): JSX.Element;
}
